#!/bin/bash

RTUSER=""
GETCONFIRMATION=1
ADMINCC=0
RTBIN=$(command -v rt)
if [[ -z $RTBIN ]] ; then
    echo "The command rt has not been found in your path."
    echo "You need to install 'rt - Command-line interface to Request Tracker'."
    exit 1
fi

function usage {
    echo "Usage: $(basename $0) [-h] [-y] -u USER"
    echo -e "\t-u user@example.com\tThe e-mail of the owner to de-assign tickets from"
    echo -e "\t-y\t\t\tProceed without confirmation"
    echo -e "\t-c\t\t\tUnassign AdminCC instead of assignee (use email address, not just username)"
    echo -e "\t-h\t\t\tShow this message"
}

while getopts ":hycu:" arg ; do
  case ${arg} in
      y)
          GETCONFIRMATION=0
          ;;
      c)
          ADMINCC=1
          ;;
      h)
          usage
          exit 1
          ;;
      u)
          RTUSER="${OPTARG}"
          ;;
      ?)
          echo "Invalid argument: ${arg}"
          usage
          exit 1
          ;;
  esac
done

if [ -z "${RTUSER}" ] ; then
  echo "Need a user"
  usage
  exit 1
fi

if [[ ! ADMINCC ]] ; then
    ticket_query="owner = ${RTUSER}"
else
    ticket_query="AdminCc = ${RTUSER}"
fi

RT_TICKETS=$(rt ls -t ticket -i "${ticket_query}" | sed 's#ticket/##g')

if [[ -z "$RT_TICKETS" ]] ; then
    echo "No tickets found for ${RTUSER}"
    exit 0
fi

if [ ${GETCONFIRMATION} == "1" ] ; then
    rt ls -t ticket -s -f subject "${ticket_query}"
    echo ""
    LINE_COUNT=$(echo "${RT_TICKETS}" | wc -l)
    if [[ ! ADMINCC ]] ; then
	echo "Found ${LINE_COUNT} tickets assigned to ${RTUSER}"
	read -r -p "Proceed with un-assigning from the above list? [Y/n] " proceed
    else
	echo "Found ${LINE_COUNT} tickets with ${RTUSER} as AdminCC"
	read -r -p "Proceed with removing with AdminCC un-assigning from the above list? [Y/n] " proceed
    fi
    if [[ ! $proceed =~ ^(y|Y|)$ ]] ; then
        echo aborting
        exit 1
    fi
fi

# There is a bug when this is run in the rt4-clients I guess
# Use of uninitialized value $list in split at /usr/bin/rt line 1642, <STDIN> line 1.
# So avoid this (easier) command for the moment
#echo ${RT_TICKETS} | rt edit -t ticket set owner=nobody -

# If the "set owner=nobody" is quoted, then the result is more like
# rt: Invalid object ID specified: '3 14 15 17 26 ....'

ticket_command=("$RTBIN" edit -t ticket)

if [[ ! ADMINCC ]] ; then
    ticket_command+=(set owner=nobody)
else
    ticket_command+=(del AdminCc="${RTUSER}")
fi

for i in ${RT_TICKETS} ; do
    "${ticket_command[@]}" "$i"
done
